@@ -1,9 +1,9 @@
 import asyncio
 
-import gbulb
-
 from gi.repository import Gtk
 
+import gbulb
+
 
 @asyncio.coroutine
 def counter(label):
@@ -17,8 +17,8 @@ def counter(label):
 @asyncio.coroutine
 def text_watcher(label):
     while True:
-        yield from gbulb.wait_signal(label, 'changed')
-        print('label changed', label.get_text())
+        yield from gbulb.wait_signal(label, "changed")
+        print("label changed", label.get_text())
 
 
 def main():
@@ -30,8 +30,8 @@ def main():
 
     vbox.pack_start(display, True, True, 0)
 
-    win = Gtk.Window(title='Counter window')
-    win.connect('delete-event', lambda *args: loop.stop())
+    win = Gtk.Window(title="Counter window")
+    win.connect("delete-event", lambda *args: loop.stop())
     win.add(vbox)
 
     win.show_all()
@@ -41,5 +41,5 @@ def main():
     loop.run_forever()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
